@@ -5,7 +5,7 @@ from bgeditor.dao.FFmpeg import create_source_can_loop, create_loop
 from bgeditor.dao.Lyric import Lyric
 from bgeditor.common.utils import download_file, get_dir
 import tempfile
-from bgeditor.dao.Component import create_video, create_image
+from bgeditor.dao.ComponentVer2 import create_video, create_image
 
 class BGEditor():
     def __init__(self):
