@@ -1,3 +1,5 @@
+import time
+
 import requests
 import os
 import tempfile
@@ -31,6 +33,7 @@ def upload_file(path, retries=3):
     rs = x[0].split(";;")[-1]
     if rs == 'None':
         if retries > 0:
+            time.sleep(10)
             return upload_file(path, retries-1)
     return rs
 def upload_file_resource(path):
